@@ -13,7 +13,7 @@
 #   limitations under the License.
 
 
-def mask(xds, name='mask1', ra=None, dec=None, pixels=None, pol=-1, channels=-1):
+def mask(xds, name='MASK1', ra=None, dec=None, pixels=None, pol=-1, channels=-1):
     """
     Create a new mask Data variable in the Dataset \n
     .. note:: This function currently only supports rectangles and integer pixel boundaries
@@ -58,22 +58,22 @@ def mask(xds, name='mask1', ra=None, dec=None, pixels=None, pol=-1, channels=-1)
     if channels[0] == -1: channels = [-1]
 
     # define mask within ra/dec range
-    mask = xr.zeros_like(xds.image, dtype=bool).where((xds.right_ascension > np.min(ra)) &
+    mask = xr.zeros_like(xds.IMAGE, dtype=bool).where((xds.right_ascension > np.min(ra)) &
                                                        (xds.right_ascension < np.max(ra)) &
                                                        (xds.declination > np.min(dec)) &
                                                        (xds.declination < np.max(dec)), True)
 
     # AND pixel values with ra/dec values
-    mask = mask & xr.zeros_like(xds.image, dtype=bool).where((xds.d0 > np.min(pixels[:, 0])) &
+    mask = mask & xr.zeros_like(xds.IMAGE, dtype=bool).where((xds.d0 > np.min(pixels[:, 0])) &
                                                                 (xds.d0 < np.max(pixels[:, 0])) &
                                                                 (xds.d1 > np.min(pixels[:, 1])) &
                                                                 (xds.d1 < np.max(pixels[:, 1])), True)
 
     # apply polarization and channels selections
     if pol[0] >= 0:
-      mask = mask & xr.zeros_like(xds.image, dtype=bool).where(xds.pol.isin(xds.pol[pol]), True)
+      mask = mask & xr.zeros_like(xds.IMAGE, dtype=bool).where(xds.pol.isin(xds.pol[pol]), True)
     if channels[0] >= 0:
-      mask = mask & xr.zeros_like(xds.image, dtype=bool).where(xds.chan.isin(xds.chan[channels]), True)
+      mask = mask & xr.zeros_like(xds.IMAGE, dtype=bool).where(xds.chan.isin(xds.chan[channels]), True)
 
     # assign region to a rest of image dataset
     xds = xds.assign(dict([(name, mask)]))
